@@ -41,18 +41,9 @@ with requests.Session() as session:
 
     def info(message, event_time_required=False):
         installed_packages = [{d.project_name: d.version} for d in pkg_resources.working_set]
-        print('installed_packages => ', installed_packages)
-
         eventTime = datetime.now().strftime("%m/%d/%Y, %H:%M:%S") if event_time_required else None
-        print('eventTime => ', eventTime)
-
         sourceFilePath = sys._getframe().f_code
-        print('sourceFilePath => ', sourceFilePath)
-
         methodName = sys._getframe(1).f_code.co_name
-        print('methodName => ', methodName)
-
-        print('version => ', __version__)
 
         detail = [
             PayloadDetail(
@@ -90,20 +81,10 @@ with requests.Session() as session:
 
     def error(occurred_error, event_time_required=False):
         message = jsonpickle.encode(occurred_error)
-
         installed_packages = [{d.project_name: d.version} for d in pkg_resources.working_set]
-        print('installed_packages => ', installed_packages)
-
         eventTime = datetime.now().strftime("%m/%d/%Y, %H:%M:%S") if event_time_required else None
-        print('eventTime => ', eventTime)
-
         sourceFilePath = sys._getframe().f_code
-        print('sourceFilePath => ', sourceFilePath)
-
         methodName = sys._getframe(1).f_code.co_name
-        print('methodName => ', methodName)
-
-        print('version => ', __version__)
 
         detail = [
             PayloadDetail(
